@@ -15,36 +15,45 @@
  *                                                                         *
  ***************************************************************************/
 
-// include files for QT
-#include <qapplication.h>
-#include <qlayout.h>
-#include <qclipboard.h>
-#include <qradiobutton.h>
-#include <qevent.h>
-#include <qpainter.h>
-#include <qstyle.h>
-#include <qgroupbox.h>
-#include <qpopupmenu.h>
-#include <qvaluestack.h>
-#include <qptrstack.h>
-#include <qwhatsthis.h>
+#include "phrasebookdialog.h"
+#include "phrasetree.h"
+
+// include files for Qt
+#include <QtGui/QApplication>
+#include <QtGui/QLayout>
+#include <QtGui/QClipboard>
+#include <QtGui/QRadioButton>
+#include <QtCore/QEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QPrintDialog>
+#include <QtGui/QStyle>
+#include <Qt3Support/Q3GroupBox>
+#include <QtGui/QMenu>
+#include <Qt3Support/Q3ValueStack>
+#include <Qt3Support/Q3PtrStack>
+#include <QtGui/QGridLayout>
+#include <QtGui/QDropEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QVBoxLayout>
+#include <Qt3Support/Q3ListViewItem>
 
 // include files for KDE
-#include <kpopupmenu.h>
+#include <ktoolbarpopupaction.h>
+#include <kmenu.h>
+#include <kxmlguifactory.h>
 #include <klocale.h>
 #include <kaction.h>
 #include <kapplication.h>
-#include <klistview.h>
+#include <k3listview.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
-#include <kdesktopfile.h> 
-
-#include "phrasebookdialog.h"
-#include "buttonboxui.h"
-#include "phrasetree.h"
+#include <kdesktopfile.h>
+#include <kactionmenu.h>
+#include <kstandardaction.h>
+#include <kdeprintdialog.h>
 
 namespace PhraseBookPrivate {
    enum columns {
@@ -53,15 +62,15 @@ namespace PhraseBookPrivate {
    };
 }
 
-CheckBookItem::CheckBookItem (QListViewItem *parent, QListViewItem *last,
+CheckBookItem::CheckBookItem (Q3ListViewItem *parent, Q3ListViewItem *last,
              const QString &text, const QString &name, const QString &filename)
-   : QCheckListItem (parent, text, QCheckListItem::CheckBox)
+   : Q3CheckListItem (parent, text, Q3CheckListItem::CheckBox)
 {
    moveItem (last);
    setText(PhraseBookPrivate::name, name);
    setText(PhraseBookPrivate::filename, filename);
    setSelectable(false);
-   
+
    if (filename.isNull() || filename.isEmpty())
       numberOfBooks = 0;
    else
@@ -70,15 +79,15 @@ CheckBookItem::CheckBookItem (QListViewItem *parent, QListViewItem *last,
    ((CheckBookItem*)parent)->childChange (numberOfBooks, selectedBooks);
 }
 
-CheckBookItem::CheckBookItem (QListView *parent, QListViewItem *last,
+CheckBookItem::CheckBookItem (Q3ListView *parent, Q3ListViewItem *last,
              const QString &text, const QString &name, const QString &filename)
-   : QCheckListItem (parent, text, QCheckListItem::CheckBox)
+   : Q3CheckListItem (parent, text, Q3CheckListItem::CheckBox)
 {
    moveItem (last);
    setText(PhraseBookPrivate::name, name);
    setText(PhraseBookPrivate::filename, filename);
    setSelectable(false);
-   
+
    if (filename.isNull() || filename.isEmpty())
       numberOfBooks = 0;
    else
@@ -90,7 +99,7 @@ CheckBookItem::~CheckBookItem () {
 }
 
 void CheckBookItem::activate() {
-   QListView *lv = listView();
+   Q3ListView *lv = listView();
 
    if ((lv != 0) && (!lv->isEnabled()) || (!isEnabled()))
       return;
@@ -100,9 +109,9 @@ void CheckBookItem::activate() {
 }
 
 void CheckBookItem::stateChange (bool on) {
-   QListViewItem *item = firstChild();
+   Q3ListViewItem *item = firstChild();
    if (item == 0) {
-      QListViewItem *parent = this->parent();
+      Q3ListViewItem *parent = this->parent();
       if (parent != 0) {
          if (on)
             ((CheckBookItem*)parent)->childChange (0, 1);
@@ -114,10 +123,10 @@ void CheckBookItem::stateChange (bool on) {
 }
 
 void CheckBookItem::propagateStateChange () {
-   QListViewItem *item = firstChild();
+   Q3ListViewItem *item = firstChild();
    while (item != 0) {
-      if (isOn() != ((QCheckListItem*)item)->isOn())
-         ((QCheckListItem*)item)->setOn (isOn());
+      if (isOn() != ((Q3CheckListItem*)item)->isOn())
+         ((Q3CheckListItem*)item)->setOn (isOn());
       else
          ((CheckBookItem*)item)->propagateStateChange ();
       item = item->nextSibling();
@@ -127,25 +136,29 @@ void CheckBookItem::propagateStateChange () {
 void CheckBookItem::childChange (int numberDiff, int selDiff) {
    numberOfBooks += numberDiff;
    selectedBooks += selDiff;
-   QListViewItem *parent = this->parent();
+   Q3ListViewItem *parent = this->parent();
    if (parent != 0)
       ((CheckBookItem*)parent)->childChange (numberDiff, selDiff);
 
-   QString text = i18n(" (%1 of %2 books selected)");
-   text = text.arg(selectedBooks).arg(numberOfBooks);
+   QString text = i18np(" (%2 of 1 book selected)",
+                        " (%2 of %1 books selected)",
+                        numberOfBooks, selectedBooks);
    setText(0, this->text(PhraseBookPrivate::name)+text);
 }
 
 /***************************************************************************/
 
 InitialPhraseBookWidget::InitialPhraseBookWidget (QWidget *parent, const char *name)
-   : QWidget(parent, name)
+   : QWidget(parent)
 {
-   QVBoxLayout *mainLayout = new QVBoxLayout (this, 0, KDialog::spacingHint());
-   QLabel *label = new QLabel (i18n("Please decide which phrase books you need:"), this, "booksTitle");
-   mainLayout->add (label);
+   setObjectName( QLatin1String( name ) );
+   QVBoxLayout *mainLayout = new QVBoxLayout (this);
+   mainLayout->setSpacing(KDialog::spacingHint());
+   QLabel *label = new QLabel (i18n("Please decide which phrase books you need:"), this);
+   label->setObjectName( QLatin1String("booksTitle" ));
+   mainLayout->addWidget (label);
 
-   books = new KListView (this, "books");
+   books = new K3ListView (this);
    books->setSorting (-1);
    books->setItemsMovable (false);
    books->setDragEnabled (false);
@@ -153,8 +166,8 @@ InitialPhraseBookWidget::InitialPhraseBookWidget (QWidget *parent, const char *n
    books->addColumn (i18n("Book"));
    books->setRootIsDecorated (true);
    books->setAllColumnsShowFocus (true);
-   books->setSelectionMode (QListView::Multi);
-   mainLayout->add (books);
+   books->setSelectionMode (Q3ListView::Multi);
+   mainLayout->addWidget (books);
 
    initStandardPhraseBooks();
 }
@@ -165,14 +178,15 @@ InitialPhraseBookWidget::~InitialPhraseBookWidget () {
 void InitialPhraseBookWidget::initStandardPhraseBooks() {
    StandardBookList bookPaths = PhraseBookDialog::standardPhraseBooks();
 
-   QListViewItem *parent = 0;
-   QListViewItem *last = 0;
-   QStringList currentNamePath = "";
-   QPtrStack<QListViewItem> stack;
+   Q3ListViewItem *parent = 0;
+   Q3ListViewItem *last = 0;
+   QStringList currentNamePath;
+   currentNamePath<<QLatin1String("");
+   Q3PtrStack<Q3ListViewItem> stack;
    StandardBookList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
       QString namePath = (*it).path;
-      QStringList dirs = QStringList::split("/", namePath);
+      QStringList dirs = namePath.split( QLatin1Char( '/' ));
 
       QStringList::iterator it1=currentNamePath.begin();
       QStringList::iterator it2=dirs.begin();
@@ -184,17 +198,17 @@ void InitialPhraseBookWidget::initStandardPhraseBooks() {
       }
       for (; it2 != dirs.end(); ++it2) {
          stack.push (parent);
-         QListViewItem *newParent;
+         Q3ListViewItem *newParent;
          if (parent == 0)
-            newParent = new CheckBookItem (books, last, *it2, *it2, QString::null);
+            newParent = new CheckBookItem (books, last, *it2, *it2, QString());
          else
-            newParent = new CheckBookItem (parent, last, *it2, *it2, QString::null);
+            newParent = new CheckBookItem (parent, last, *it2, *it2, QString());
          parent = newParent;
          last = 0;
       }
       currentNamePath = dirs;
-      
-      QListViewItem *book;
+
+      Q3ListViewItem *book;
       if (parent == 0)
          book = new CheckBookItem (books, last, (*it).name, (*it).name, (*it).filename);
       else
@@ -205,18 +219,18 @@ void InitialPhraseBookWidget::initStandardPhraseBooks() {
 
 void InitialPhraseBookWidget::createBook () {
    PhraseBook book;
-   QListViewItem *item = books->firstChild();
+   Q3ListViewItem *item = books->firstChild();
    while (item != 0) {
       if (item->firstChild() != 0) {
          item = item->firstChild();
       }
       else {
-         if (((QCheckListItem*)item)->isOn()) {
+         if (((Q3CheckListItem*)item)->isOn()) {
             PhraseBook localBook;
-            localBook.open(KURL( item->text(PhraseBookPrivate::filename )));
+            localBook.open(KUrl( item->text(PhraseBookPrivate::filename )));
             book += localBook;
          }
-         
+
          while ((item != 0) && (item->nextSibling() == 0)) {
             item = item->parent();
          }
@@ -225,23 +239,29 @@ void InitialPhraseBookWidget::createBook () {
       }
    }
 
-   QString bookLocation = KApplication::kApplication()->dirs()->saveLocation ("appdata", "/");
+   QString bookLocation = KGlobal::dirs()->saveLocation ("appdata", QLatin1String( "/" ));
    if (!bookLocation.isNull() && !bookLocation.isEmpty()) {
-      book.save (KURL( bookLocation + "standard.phrasebook" ));
+      book.save (KUrl( bookLocation + QLatin1String( "standard.phrasebook" ) ));
    }
 }
 
 /***************************************************************************/
 
 ButtonBoxWidget::ButtonBoxWidget (QWidget *parent, const char *name)
-: ButtonBoxUI (parent, name) {
-   keyButtonPlaceLayout = new QGridLayout (keyButtonPlace, 1, 1, 0, 0, "keyButtonPlaceLayout");
+: QWidget(parent)
+{
+   setupUi(this);
+   setObjectName( QLatin1String( name ) );
+   keyButtonPlaceLayout = new QGridLayout (keyButtonPlace);
+   keyButtonPlaceLayout->setObjectName( QLatin1String("keyButtonPlaceLayout" ));
+   keyButtonPlaceLayout->setMargin(0);
+   keyButtonPlaceLayout->setSpacing(0);
 
-   keyButton = new KKeyButton (keyButtonPlace, "key");
+   keyButton = new KKeySequenceWidget (keyButtonPlace);
    keyButtonPlaceLayout->addWidget (keyButton, 1,1);
-   QWhatsThis::add (keyButton, i18n("By clicking on this button you can select the keyboard shortcut associated with the selected phrase."));
+   keyButton->setWhatsThis( i18n("By clicking on this button you can select the keyboard shortcut associated with the selected phrase."));
 
-   group = new QButtonGroup (phrasebox);
+   group = new Q3ButtonGroup (phrasebox);
    group->hide();
    group->setExclusive (true);
    group->insert (noKey);
@@ -258,22 +278,25 @@ namespace PhraseBookPrivate {
 }
 
 PhraseBookDialog::PhraseBookDialog ()
- : KMainWindow (0, "phraseEditDialog")
+ : KXmlGuiWindow (0)
 {
+   setObjectName( QLatin1String("phraseEditDialog" ));
    setCaption (i18n("Phrase Book"));
    initGUI();
    initActions();
    initStandardPhraseBooks();
-   QString standardBook = KApplication::kApplication()->dirs()->findResource("appdata", "standard.phrasebook");
+   QString standardBook = KGlobal::dirs()->findResource("appdata", QLatin1String( "standard.phrasebook" ));
    if (!standardBook.isNull() && !standardBook.isEmpty()) {
       PhraseBook book;
-      book.open(KURL( standardBook ));
+      book.open(KUrl( standardBook ));
       treeView->clear();
       treeView->addBook(0, 0, &book);
       treeView->setCurrentItem(treeView->firstChild());
       selectionChanged();
       phrasebookChanged = false;
    }
+
+   printer = 0;
    // i18n("Edit Phrase Book")
 }
 
@@ -285,13 +308,15 @@ PhraseBookDialog *PhraseBookDialog::get() {
 
 PhraseBookDialog::~PhraseBookDialog() {
    PhraseBookPrivate::instance = 0;
+   delete printer;
 }
 
 void PhraseBookDialog::initGUI () {
    QWidget *page = new QWidget( this );
    setCentralWidget(page);
-   QVBoxLayout *mainLayout = new QVBoxLayout (page, 0);
-   
+   QVBoxLayout *mainLayout = new QVBoxLayout (page);
+   mainLayout->setMargin(0);
+
    treeView = new PhraseTree (page, "phrasetree");
    treeView->setSorting (-1);
    treeView->setItemsMovable (true);
@@ -301,14 +326,14 @@ void PhraseBookDialog::initGUI () {
    treeView->addColumn (i18n("Shortcut"));
    treeView->setRootIsDecorated (true);
    treeView->setAllColumnsShowFocus (true);
-   treeView->setSelectionMode (QListView::Extended); 
-   QWhatsThis::add (treeView, i18n("This list contains the current phrase book in a tree structure. You can select and modify individual phrases and sub phrase books"));
+   treeView->setSelectionMode (Q3ListView::Extended);
+   treeView->setWhatsThis( i18n("This list contains the current phrase book in a tree structure. You can select and modify individual phrases and sub phrase books"));
    connect (treeView, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
-   connect (treeView, SIGNAL(contextMenuRequested (QListViewItem *, const QPoint &, int)), this, SLOT(contextMenuRequested (QListViewItem *, const QPoint &, int)));
-   connect (treeView, SIGNAL(dropped (QDropEvent *, QListViewItem *, QListViewItem *)), this, SLOT(slotDropped (QDropEvent *, QListViewItem *, QListViewItem *)));
-   connect (treeView, SIGNAL(moved (QListViewItem *, QListViewItem *, QListViewItem *)), this, SLOT(slotMoved (QListViewItem *, QListViewItem *, QListViewItem *)));
+   connect (treeView, SIGNAL(contextMenuRequested (Q3ListViewItem *, const QPoint &, int)), this, SLOT(contextMenuRequested (Q3ListViewItem *, const QPoint &, int)));
+   connect (treeView, SIGNAL(dropped (QDropEvent *, Q3ListViewItem *, Q3ListViewItem *)), this, SLOT(slotDropped (QDropEvent *, Q3ListViewItem *, Q3ListViewItem *)));
+   connect (treeView, SIGNAL(moved (Q3ListViewItem *, Q3ListViewItem *, Q3ListViewItem *)), this, SLOT(slotMoved (Q3ListViewItem *, Q3ListViewItem *, Q3ListViewItem *)));
    mainLayout->addWidget (treeView);
-   
+
    buttonBox = new ButtonBoxWidget (page, "buttonbox");
    connect (buttonBox->lineEdit, SIGNAL(textChanged(const QString &)), SLOT(slotTextChanged(const QString &)));
    connect (buttonBox->noKey, SIGNAL(clicked()), SLOT(slotNoKey()));
@@ -322,103 +347,124 @@ void PhraseBookDialog::initGUI () {
 
 void PhraseBookDialog::initActions() {
 // The file menu
-   fileNewPhrase = new KAction (i18n("&New Phrase"), "phrase_new", 0, this, SLOT(slotAddPhrase()), actionCollection(),"file_new_phrase");
-   fileNewPhrase->setStatusText(i18n("Adds a new phrase"));
+   fileNewPhrase = actionCollection()->addAction(QLatin1String( "file_new_phrase" ));
+   fileNewPhrase->setIcon(KIcon( QLatin1String( "phrase_new" )));
+   fileNewPhrase->setText(i18n("&New Phrase"));
+   connect(fileNewPhrase, SIGNAL(triggered(bool)), this, SLOT(slotAddPhrase()));
+   fileNewPhrase->setToolTip(i18n("Adds a new phrase"));
    fileNewPhrase->setWhatsThis (i18n("Adds a new phrase"));
 
-   fileNewBook = new KAction (i18n("New Phrase &Book"), "phrasebook_new", 0, this, SLOT(slotAddPhrasebook()), actionCollection(),"file_new_book");
-   fileNewBook->setStatusText(i18n("Adds a new phrase book into which other books and phrases can be placed"));
+   fileNewBook = actionCollection()->addAction(QLatin1String( "file_new_book" ));
+   fileNewBook->setIcon(KIcon( QLatin1String( "phrasebook_new" )));
+   fileNewBook->setText(i18n("New Phrase &Book"));
+   connect(fileNewBook, SIGNAL(triggered(bool)), this, SLOT(slotAddPhrasebook()));
+   fileNewBook->setToolTip(i18n("Adds a new phrase book into which other books and phrases can be placed"));
    fileNewBook->setWhatsThis (i18n("Adds a new phrase book into which other books and phrases can be placed"));
 
-   fileSave = KStdAction::save(this, SLOT(slotSave()), actionCollection());
-   fileSave->setStatusText(i18n("Saves the phrase book onto the hard disk"));
+   fileSave = KStandardAction::save(this, SLOT(slotSave()), actionCollection());
+   fileSave->setToolTip(i18n("Saves the phrase book onto the hard disk"));
    fileSave->setWhatsThis (i18n("Saves the phrase book onto the hard disk"));
 
-   fileImport = new KAction (i18n("&Import..."), "phrasebook_open", 0, this, SLOT(slotImportPhrasebook()), actionCollection(),"file_import");
-   fileImport->setStatusText(i18n("Imports a file and adds its contents to the phrase book"));
+   fileImport = actionCollection()->addAction(QLatin1String( "file_import" ));
+   fileImport->setIcon(KIcon( QLatin1String( "phrasebook_open" )));
+   fileImport->setText(i18n("&Import..."));
+   connect(fileImport, SIGNAL(triggered(bool)), this, SLOT(slotImportPhrasebook()));
+   fileImport->setToolTip(i18n("Imports a file and adds its contents to the phrase book"));
    fileImport->setWhatsThis (i18n("Imports a file and adds its contents to the phrase book"));
 
-   toolbarImport = new KToolBarPopupAction (i18n("&Import..."), "phrasebook_open", 0, this, SLOT(slotImportPhrasebook()), actionCollection(),"toolbar_import");
-   toolbarImport->setStatusText(i18n("Imports a file and adds its contents to the phrase book"));
+   toolbarImport = new KToolBarPopupAction(KIcon( QLatin1String( "phrasebook_open") ), i18n("&Import..." ), this);
+   actionCollection()->addAction(QLatin1String( "toolbar_import" ), toolbarImport);
+   connect(toolbarImport, SIGNAL(triggered(bool)), this, SLOT(slotImportPhrasebook()));
+   toolbarImport->setToolTip(i18n("Imports a file and adds its contents to the phrase book"));
    toolbarImport->setWhatsThis (i18n("Imports a file and adds its contents to the phrase book"));
 
-   fileImportStandardBook = new KActionMenu (i18n("I&mport Standard Phrase Book"), "phrasebook_open", actionCollection(),"file_import_standard_book");
-   fileImportStandardBook->setStatusText(i18n("Imports a standard phrase book and adds its contents to the phrase book"));
+   fileImportStandardBook = actionCollection()->add<KActionMenu>(QLatin1String( "file_import_standard_book" ));
+   fileImportStandardBook->setIcon(KIcon( QLatin1String( "phrasebook_open" )));
+   fileImportStandardBook->setText(i18n("I&mport Standard Phrase Book"));
+   fileImportStandardBook->setToolTip(i18n("Imports a standard phrase book and adds its contents to the phrase book"));
    fileImportStandardBook->setWhatsThis (i18n("Imports a standard phrase book and adds its contents to the phrase book"));
 
-   fileExport = new KAction (i18n("&Export..."), "phrasebook_save", 0, this, SLOT(slotExportPhrasebook()), actionCollection(),"file_export");
-   fileExport->setStatusText(i18n("Exports the currently selected phrase(s) or phrase book(s) into a file"));
+   fileExport = actionCollection()->addAction(QLatin1String( "file_export" ));
+   fileExport->setIcon(KIcon( QLatin1String( "phrasebook_save" )));
+   fileExport->setText(i18n("&Export..."));
+   connect(fileExport, SIGNAL(triggered(bool)), this, SLOT(slotExportPhrasebook()));
+   fileExport->setToolTip(i18n("Exports the currently selected phrase(s) or phrase book(s) into a file"));
    fileExport->setWhatsThis (i18n("Exports the currently selected phrase(s) or phrase book(s) into a file"));
 
-   filePrint = KStdAction::print(this, SLOT(slotPrint()), actionCollection());
-   filePrint->setStatusText(i18n("Prints the currently selected phrase(s) or phrase book(s)"));
+   filePrint = KStandardAction::print(this, SLOT(slotPrint()), actionCollection());
+   filePrint->setToolTip(i18n("Prints the currently selected phrase(s) or phrase book(s)"));
    filePrint->setWhatsThis (i18n("Prints the currently selected phrase(s) or phrase book(s)"));
 
-   fileClose = KStdAction::close(this, SLOT(close()), actionCollection());
-   fileClose->setStatusText(i18n("Closes the window"));
+   fileClose = KStandardAction::close(this, SLOT(close()), actionCollection());
+   fileClose->setToolTip(i18n("Closes the window"));
    fileClose->setWhatsThis (i18n("Closes the window"));
 
 // The edit menu
-   editCut = KStdAction::cut(this, SLOT(slotCut()), actionCollection());
-   editCut->setStatusText(i18n("Cuts the currently selected entries from the phrase book and puts it to the clipboard"));
+   editCut = KStandardAction::cut(this, SLOT(slotCut()), actionCollection());
+   editCut->setToolTip(i18n("Cuts the currently selected entries from the phrase book and puts it to the clipboard"));
    editCut->setWhatsThis (i18n("Cuts the currently selected entries from the phrase book and puts it to the clipboard"));
 
-   editCopy = KStdAction::copy(this, SLOT(slotCopy()), actionCollection());
-   editCopy->setStatusText(i18n("Copies the currently selected entry from the phrase book to the clipboard"));
+   editCopy = KStandardAction::copy(this, SLOT(slotCopy()), actionCollection());
+   editCopy->setToolTip(i18n("Copies the currently selected entry from the phrase book to the clipboard"));
    editCopy->setWhatsThis (i18n("Copies the currently selected entry from the phrase book to the clipboard"));
 
-   editPaste = KStdAction::paste(this, SLOT(slotPaste()), actionCollection());
-   editPaste->setStatusText(i18n("Pastes the clipboard contents to actual position"));
-   editPaste->setWhatsThis (i18n("Pastes the clipboard contents to actual position"));
+   editPaste = KStandardAction::paste(this, SLOT(slotPaste()), actionCollection());
+   editPaste->setToolTip(i18n("Pastes the clipboard contents to current position"));
+   editPaste->setWhatsThis(i18n("Pastes the clipboard contents at the current cursor position into the edit field."));
 
-   editDelete = new KAction (i18n("&Delete"), "editdelete", 0, this, SLOT(slotRemove()), actionCollection(),"edit_delete");
-   editDelete->setStatusText(i18n("Deletes the selected entries from the phrase book"));
+   editDelete = actionCollection()->addAction(QLatin1String( "edit_delete" ));
+   editDelete->setIcon(KIcon( QLatin1String( "edit-delete" )));
+   editDelete->setText(i18n("&Delete"));
+   connect(editDelete, SIGNAL(triggered(bool)), this, SLOT(slotRemove()));
+   editDelete->setToolTip(i18n("Deletes the selected entries from the phrase book"));
    editDelete->setWhatsThis (i18n("Deletes the selected entries from the phrase book"));
 
    // use the absolute path to your kmouthui.rc file for testing purpose in createGUI();
-   createGUI("phrasebookdialogui.rc");
+   createGUI(QLatin1String( "phrasebookdialogui.rc" ));
 }
 
 QString PhraseBookDialog::displayPath (QString filename) {
    QFileInfo file(filename);
-   QString path = file.dirPath();
-   QString dispPath = "";
-   uint position = path.find("/kmouth/books/")+QString("/kmouth/books/").length();
+   QString path = file.path();
+   QString dispPath;
+   int position = path.indexOf(QLatin1String( "/kmouth/books/" ))+QString( QLatin1String("/kmouth/books/") ).length();
 
    while (path.length() > position) {
       file.setFile(path);
 
-      KDesktopFile *dirDesc = new KDesktopFile(path+"/.directory", true, "data");
+      KDesktopFile *dirDesc = new KDesktopFile("data", path+QLatin1String( "/.directory" ));
       QString name = dirDesc->readName();
       delete dirDesc;
 
       if (name.isNull() || name.isEmpty())
-         dispPath += "/" + file.fileName ();
+         dispPath += QLatin1Char( '/' ) + file.fileName ();
       else
-         dispPath += "/" + name;
+         dispPath += QLatin1Char( '/' ) + name;
 
-      path = file.dirPath();
+      path = file.path();
    }
    return dispPath;
 }
 
 StandardBookList PhraseBookDialog::standardPhraseBooks() {
-   QStringList bookPaths = KGlobal::instance()->dirs()->findAllResources (
-                          "data", "kmouth/books/*.phrasebook", true, true);
+   QStringList bookPaths = KGlobal::mainComponent().dirs()->findAllResources (
+                          "data", QLatin1String( "kmouth/books/*.phrasebook" ),
+                          KStandardDirs::Recursive |
+                          KStandardDirs::NoDuplicates);
    QStringList bookNames;
    QMap<QString,StandardBook> bookMap;
    QStringList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
       PhraseBook pbook;
-      if (pbook.open (KURL( *it ))) {
+      if (pbook.open (KUrl( *it ))) {
          StandardBook book;
          book.name = (*pbook.begin()).getPhrase().getPhrase();
-         
+
          book.path = displayPath(*it);
          book.filename = *it;
-      
-         bookNames += book.path + "/" + book.name;
-         bookMap [book.path + "/" + book.name] = book;
+
+         bookNames += book.path + QLatin1Char( '/' ) + book.name;
+         bookMap [book.path + QLatin1Char( '/' ) + book.name] = book;
       }
    }
 
@@ -433,17 +479,18 @@ StandardBookList PhraseBookDialog::standardPhraseBooks() {
 
 void PhraseBookDialog::initStandardPhraseBooks () {
    StandardBookList bookPaths = standardPhraseBooks();
-   
+
    KActionMenu *parent = fileImportStandardBook;
-   QStringList currentNamePath = "x";
-   QPtrStack<KActionMenu> stack;
+   QStringList currentNamePath;
+   currentNamePath<< QLatin1String( "x" );
+   Q3PtrStack<KActionMenu> stack;
    StandardBookList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
-      KURL url;
+      KUrl url;
       url.setPath((*it).filename);
 
-      QString namePath = "x/"+(*it).path;
-      QStringList dirs = QStringList::split("/", namePath);
+      QString namePath = QLatin1String( "x/" )+(*it).path;
+      QStringList dirs = namePath.split(QLatin1Char(  '/' ));
 
       QStringList::iterator it1=currentNamePath.begin();
       QStringList::iterator it2=dirs.begin();
@@ -453,30 +500,34 @@ void PhraseBookDialog::initStandardPhraseBooks () {
          parent = stack.pop();
       for (; it2 != dirs.end(); ++it2) {
          stack.push (parent);
-         KActionMenu *newParent = new KActionMenu (*it2);
-         parent->insert(newParent);
+#ifdef __GNUC__
+#warning "kde4: correct newparent objectname ?"
+#endif
+         KActionMenu *newParent = actionCollection()->add<KActionMenu>(QLatin1String( "tmp_menu" ));
+         newParent->setText(*it2);
+         parent->addAction(newParent);
          if (parent == fileImportStandardBook)
-            newParent->plug(toolbarImport->popupMenu());
+            toolbarImport->popupMenu()->addAction(newParent);
          parent = newParent;
       }
       currentNamePath = dirs;
-      
+
       KAction *book = new StandardPhraseBookInsertAction (
-          url, (*it).name, this, SLOT(slotImportPhrasebook (const KURL &)), actionCollection());
-      parent->insert(book);
+          url, (*it).name, this, SLOT(slotImportPhrasebook (const KUrl &)), actionCollection());
+      parent->addAction(book);
       if (parent == fileImportStandardBook)
-         book->plug(toolbarImport->popupMenu());
+         toolbarImport->popupMenu()->addAction(book);
    }
 }
 
-PhraseTreeItem *selectedItem (QListView *treeView) {
+PhraseTreeItem *selectedItem (Q3ListView *treeView) {
    PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
    if ((currentItem == 0) || (!currentItem->isSelected()))
       return 0;
 
-   QListViewItemIterator it(treeView);
+   Q3ListViewItemIterator it(treeView);
    while (it.current()) {
-      QListViewItem *item = it.current();
+      Q3ListViewItem *item = it.current();
       if (item->isSelected() && (item != currentItem))
          return 0;
       ++it;
@@ -491,10 +542,10 @@ void PhraseBookDialog::selectionChanged () {
       buttonBox->textLabel->setText (i18n("Text of the &phrase:"));
       buttonBox->textLabel->setEnabled(false);
       buttonBox->group->setEnabled(false);
-      buttonBox->lineEdit->setText("");
+      buttonBox->lineEdit->setText(QLatin1String( "" ));
       buttonBox->lineEdit->setEnabled(false);
       buttonBox->shortcutLabel->setEnabled(false);
-      buttonBox->keyButton->setShortcut("", false);
+      //buttonBox->keyButton->setShortcut("", false);
       buttonBox->keyButton->setEnabled(false);
       buttonBox->noKey->setChecked (false);
       buttonBox->noKey->setEnabled (false);
@@ -509,7 +560,10 @@ void PhraseBookDialog::selectionChanged () {
       buttonBox->lineEdit->setEnabled(true);
       buttonBox->shortcutLabel->setEnabled(true);
       QString shortcut = currentItem->text(1);
-      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
+#ifdef __GNUC__
+#warning "kde4 port it"
+#endif
+      //buttonBox->keyButton->setShortcut(currentItem->cut(), false);
       if (shortcut.isEmpty() || shortcut.isNull()) {
          buttonBox->noKey->setChecked (true);
          buttonBox->customKey->setChecked (false);
@@ -529,7 +583,7 @@ void PhraseBookDialog::selectionChanged () {
       buttonBox->lineEdit->setText(currentItem->text(0));
       buttonBox->lineEdit->setEnabled(true);
       buttonBox->shortcutLabel->setEnabled(false);
-      buttonBox->keyButton->setShortcut("", false);
+      //buttonBox->keyButton->setShortcut("", false);
       buttonBox->keyButton->setEnabled(false);
       buttonBox->noKey->setChecked (false);
       buttonBox->noKey->setEnabled (false);
@@ -542,9 +596,10 @@ void PhraseBookDialog::selectionChanged () {
 bool PhraseBookDialog::queryClose() {
    if (phrasebookChanged) {
       int answer = KMessageBox::questionYesNoCancel (this,
-              i18n("<qt>There are unsaved changes.<br>Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?</qt>"),
-          i18n("Closing \"Phrase Book\" Window"),
-          KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
+              i18n("<qt>There are unsaved changes.<br />Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?</qt>"),
+              i18n("Closing \"Phrase Book\" Window"),
+              KStandardGuiItem::apply(), KStandardGuiItem::discard(),
+              KStandardGuiItem::cancel(), QLatin1String( "AutomaticSave" ));
       if (answer == KMessageBox::Yes) {
          slotSave();
          return true;
@@ -564,21 +619,24 @@ void PhraseBookDialog::slotTextChanged (const QString &s) {
 void PhraseBookDialog::slotNoKey() {
    buttonBox->noKey->setChecked (true);
    buttonBox->customKey->setChecked (false);
-   
+
    PhraseTreeItem *currentItem = selectedItem (treeView);
    if (currentItem != 0) {
-      currentItem->setCut (KShortcut(QString::null));
-      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
+      currentItem->setCut (KShortcut(QString()));
+#ifdef __GNUC__
+#warning "kde4: port it"
+#endif
+	  //buttonBox->keyButton->setShortcut(currentItem->cut(), false);
    }
    phrasebookChanged = true;
 }
 
 void PhraseBookDialog::slotCustomKey() {
-   buttonBox->keyButton->captureShortcut();
+   buttonBox->keyButton->keySequence();
 }
 
 void PhraseBookDialog::capturedShortcut (const KShortcut& cut) {
-   if (cut.isNull()) {
+   if (cut.isEmpty()) {
       slotNoKey();
    }
    else
@@ -588,21 +646,25 @@ void PhraseBookDialog::capturedShortcut (const KShortcut& cut) {
 
 void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
    // Check whether the shortcut is valid
-   for (uint i = 0; i < cut.count(); i++) {
-      const KKeySequence& seq = cut.seq(i);
-      const KKey& key = seq.key(0);
-
+   const QList<QKeySequence> cutList = cut.toList();
+   for (int i = 0; i < cutList.count(); i++) {
+      const QKeySequence& seq = cutList[i];
+      //const KKey& key = seq.key(0);
+#ifdef __GNUC__
+#warning "kde 4 port it";
+#endif
+#if 0
       if (key.modFlags() == 0 && key.sym() < 0x3000
           && QChar(key.sym()).isLetterOrNumber())
       {
          QString s = i18n("In order to use the '%1' key as a shortcut, "
                           "it must be combined with the "
-                          "Win, Alt, Ctrl, and/or Shift keys.").arg(QChar(key.sym()));
+                          "Win, Alt, Ctrl, and/or Shift keys.", QChar(key.sym()));
          KMessageBox::sorry( this, s, i18n("Invalid Shortcut Key") );
          return;
       }
+#endif
    }
-
    PhraseTreeItem *currentItem = selectedItem (treeView);
    // If key isn't already in use,
    if (!treeView->isKeyPresent (cut, currentItem, true)) {
@@ -611,12 +673,12 @@ void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
       // Update display
       buttonBox->noKey->setChecked (false);
       buttonBox->customKey->setChecked (true);
-      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
+      buttonBox->keyButton->setKeySequence(currentItem->cut().primary());
    }
 }
 
-QListViewItem *PhraseBookDialog::addBook (QListViewItem *parent, QListViewItem *after, PhraseBook *book) {
-   QListViewItem *newItem = treeView->addBook(parent, after, book);
+Q3ListViewItem *PhraseBookDialog::addBook (Q3ListViewItem *parent, Q3ListViewItem *after, PhraseBook *book) {
+   Q3ListViewItem *newItem = treeView->addBook(parent, after, book);
    if (newItem != 0) {
       treeView->clearSelection();
       treeView->ensureItemVisible(newItem);
@@ -627,7 +689,7 @@ QListViewItem *PhraseBookDialog::addBook (QListViewItem *parent, QListViewItem *
    return newItem;
 }
 
-QListViewItem *PhraseBookDialog::addBook (QListViewItem *item, PhraseBook *book) {
+Q3ListViewItem *PhraseBookDialog::addBook (Q3ListViewItem *item, PhraseBook *book) {
    if (item == 0)
       return addBook(0, 0, book);
    else if (((PhraseTreeItem *)item)->isPhrase() || !item->isOpen())
@@ -639,14 +701,14 @@ QListViewItem *PhraseBookDialog::addBook (QListViewItem *item, PhraseBook *book)
       return addBook(item, 0, book);
 }
 
-void PhraseBookDialog::contextMenuRequested(QListViewItem *, const QPoint &pos, int) {
+void PhraseBookDialog::contextMenuRequested(Q3ListViewItem *, const QPoint &pos, int) {
    QString name;
    if (treeView->hasSelectedItems())
-      name = "phrasebook_popup_sel";
+      name = QLatin1String( "phrasebook_popup_sel" );
    else
-      name = "phrasebook_popup_nosel";
+      name = QLatin1String( "phrasebook_popup_nosel" );
 
-   QPopupMenu *popup = (QPopupMenu *)factory()->container(name,this);
+   QMenu *popup = (QMenu *)factory()->container(name,this);
    if (popup != 0) {
       popup->popup(pos, 0);
    }
@@ -667,6 +729,9 @@ void PhraseBookDialog::slotCut () {
 void PhraseBookDialog::slotCopy () {
    PhraseBook book;
    treeView->fillBook (&book, true);
+#ifdef __GNUC__
+#warning "kde4: port to QMimeData"
+#endif
    QApplication::clipboard()->setData(new PhraseBookDrag(&book));
 }
 
@@ -677,14 +742,14 @@ void PhraseBookDialog::slotPaste () {
    }
 }
 
-void PhraseBookDialog::slotDropped (QDropEvent *e, QListViewItem *parent, QListViewItem *after) {
+void PhraseBookDialog::slotDropped (QDropEvent *e, Q3ListViewItem *parent, Q3ListViewItem *after) {
    PhraseBook book;
    if (PhraseBookDrag::decode(e, &book)) {
       addBook(parent, after, &book);
    }
 }
 
-void PhraseBookDialog::slotMoved (QListViewItem *item, QListViewItem *, QListViewItem *) {
+void PhraseBookDialog::slotMoved (Q3ListViewItem *item, Q3ListViewItem *, Q3ListViewItem *) {
    treeView->ensureItemVisible(item);
    treeView->setSelected (item, true);
    phrasebookChanged = true;
@@ -692,10 +757,10 @@ void PhraseBookDialog::slotMoved (QListViewItem *item, QListViewItem *, QListVie
 
 void PhraseBookDialog::slotAddPhrasebook () {
    PhraseBook book;
-   Phrase phrase(i18n("(New Phrase Book)"), "");
+   Phrase phrase(i18n("(New Phrase Book)"), QLatin1String( "" ));
    book += PhraseBookEntry(phrase, 0, false);
 
-   QListViewItem *item = addBook (treeView->currentItem(), &book);
+   Q3ListViewItem *item = addBook (treeView->currentItem(), &book);
    item->setOpen (true);
    buttonBox->lineEdit->selectAll();
    buttonBox->lineEdit->setFocus();
@@ -703,7 +768,7 @@ void PhraseBookDialog::slotAddPhrasebook () {
 
 void PhraseBookDialog::slotAddPhrase () {
    PhraseBook book;
-   Phrase phrase(i18n("(New Phrase)"), "");
+   Phrase phrase(i18n("(New Phrase)"), QLatin1String( "" ));
    book += PhraseBookEntry(phrase, 0, true);
 
    addBook (treeView->currentItem(), &book);
@@ -719,40 +784,46 @@ void PhraseBookDialog::slotSave () {
 }
 
 void PhraseBookDialog::slotImportPhrasebook () {
-   KURL url=KFileDialog::getOpenURL(QString::null,
+   KUrl url=KFileDialog::getOpenUrl(KUrl(),
         i18n("*.phrasebook|Phrase Books (*.phrasebook)\n*.txt|Plain Text Files (*.txt)\n*|All Files"), this, i18n("Import Phrasebook"));
 
    slotImportPhrasebook (url);
 }
 
-void PhraseBookDialog::slotImportPhrasebook (const KURL &url) {
+void PhraseBookDialog::slotImportPhrasebook (const KUrl &url) {
    if(!url.isEmpty()) {
       PhraseBook book;
       if (book.open (url))
          addBook(treeView->currentItem(), &book);
       else
-         KMessageBox::sorry(this,i18n("There was an error loading file\n%1").arg( url.url() ));
+         KMessageBox::sorry(this,i18n("There was an error loading file\n%1", url.url() ));
    }
 }
 
 void PhraseBookDialog::slotExportPhrasebook () {
    PhraseBook book;
    treeView->fillBook (&book, treeView->hasSelectedItems());
-   
-   KURL url;
+
+   KUrl url;
    if (book.save (this, i18n("Export Phrase Book"), url) == -1)
-      KMessageBox::sorry(this,i18n("There was an error saving file\n%1").arg( url.url() ));
+      KMessageBox::sorry(this,i18n("There was an error saving file\n%1", url.url() ));
 }
 
 void PhraseBookDialog::slotPrint()
 {
-   KPrinter printer;
-   if (printer.setup(this)) {
+   if (printer == 0) {
+     printer = new QPrinter();
+   }
+
+   QPrintDialog *printDialog = KdePrint::createPrintDialog(printer, this);
+
+   if (printDialog->exec()) {
       PhraseBook book;
       treeView->fillBook (&book, treeView->hasSelectedItems());
-      
-      book.print(&printer);
+
+      book.print(printer);
    }
+   delete printDialog;
 }
 
 #include "phrasebookdialog.moc"
